@@ -37,7 +37,6 @@
 #include <sys/types.h>
 #include <fcntl.h>
 #include <glib.h>
-#include <popt.h>
 #include <signal.h>
 #include <stdlib.h>
 #include <string.h>
@@ -461,7 +460,7 @@ bonobo_activation_postinit (gpointer app, gpointer mod_info)
 
         if (bonobo_activation_activate_iid)
                 g_timeout_add_full (G_PRIORITY_LOW,
-                                    BONOBO_ACTIVATION_FACTORY_TIMEOUT,
+                                    BONOBO_ACTIVATION_FACTORY_PRIVATE_TIMEOUT,
                                     bonobo_activation_timeout_reg_check,
                                     NULL, NULL);
         else
@@ -539,6 +538,8 @@ bonobo_activation_init (int argc, char **argv)
 
                 retval = bonobo_activation_orb_init (&argc, argv);
         }
+	else
+		retval = bonobo_activation_orb;
 
         /* Accumulate arguments over multiple inits. Sometimes we are
          * initialized from GTK_MODULEs or gnome-vfs with bogus arguments */
@@ -582,7 +583,7 @@ bonobo_activation_orb_init (int *argc, char **argv)
         CORBA_Context def_ctx;
 	CORBA_Environment ev;
 	const char *hostname;
-	const gchar *orb_id;
+	gchar *orb_id;
 
 	CORBA_exception_init (&ev);
 
